@@ -1,6 +1,7 @@
 """The iCloudPy library."""
+
 import logging
 
-from icloudpy.base import ICloudPyService  # pylint: disable=unused-import
+from icloudpy.base import ICloudPyService  # # noqa: F401
 
 logging.getLogger(__name__).addHandler(logging.NullHandler())
