@@ -1,5 +1,8 @@
 """Library base file."""
+
+import base64
 import getpass
+import hashlib
 import http.cookiejar as cookielib
 import inspect
 import json
@@ -9,8 +12,8 @@ from re import match
 from tempfile import gettempdir
 from uuid import uuid1
 
+import srp
 from requests import Session
-from six import PY2
 
 from icloudpy.exceptions import (
     ICloudPy2SARequiredException,
@@ -26,7 +29,6 @@ from icloudpy.services import (
     FindMyiPhoneServiceManager,
     PhotosService,
     RemindersService,
-    UbiquityService,
 )
 from icloudpy.utils import get_password_from_keyring
 
@@ -64,7 +66,6 @@ class ICloudPySession(Session):
         Session.__init__(self)
 
     def request(self, method, url, **kwargs):  # pylint: disable=arguments-differ
-
         # Charge logging to the right service endpoint
         callee = inspect.stack()[2]
         module = inspect.getmodule(callee[0])
@@ -85,7 +86,7 @@ class ICloudPySession(Session):
             if response.headers.get(header):
                 session_arg = value
                 self.service.session_data.update(
-                    {session_arg: response.headers.get(header)}
+                    {session_arg: response.headers.get(header)},
                 )
 
         # Save session_data to file
@@ -97,18 +98,11 @@ class ICloudPySession(Session):
         self.cookies.save(ignore_discard=True, ignore_expires=True)
         LOGGER.debug("Cookies saved to %s", self.service.cookiejar_path)
 
-        if not response.ok and (
-            content_type not in json_mimetypes
-            or response.status_code in [421, 450, 500]
-        ):
+        if not response.ok and (content_type not in json_mimetypes or response.status_code in [421, 450, 500]):
             try:
                 # pylint: disable=W0212
                 fmip_url = self.service._get_webservice_url("findme")
-                if (
-                    has_retried is None
-                    and response.status_code == 450
-                    and fmip_url in url
-                ):
+                if has_retried is None and response.status_code == 450 and fmip_url in url:
                     # Handle re-authentication for Find My iPhone
                     LOGGER.debug("Re-authenticating Find My iPhone service")
                     try:
@@ -122,7 +116,9 @@ class ICloudPySession(Session):
 
             if has_retried is None and response.status_code in [421, 450, 500]:
                 api_error = ICloudPyAPIResponseException(
-                    response.reason, response.status_code, retry=True
+                    response.reason,
+                    response.status_code,
+                    retry=True,
                 )
                 request_logger.debug(api_error)
                 kwargs["retried"] = True
@@ -135,7 +131,7 @@ class ICloudPySession(Session):
 
         try:
             data = response.json()
-        except:  # pylint: disable=bare-except
+        except:  # noqa: E722
             request_logger.warning("Failed to parse response with JSON mimetype")
             return response
 
@@ -160,16 +156,10 @@ class ICloudPySession(Session):
         return response
 
     def _raise_error(self, code, reason):
-        if (
-            self.service.requires_2sa
-            and reason == "Missing X-APPLE-WEBAUTH-TOKEN cookie"
-        ):
+        if self.service.requires_2sa and reason == "Missing X-APPLE-WEBAUTH-TOKEN cookie":
             raise ICloudPy2SARequiredException(self.service.user["apple_id"])
         if code in ("ZONE_NOT_FOUND", "AUTHENTICATION_FAILED"):
-            reason = (
-                reason + ". Please log into https://icloud.com/ to manually "
-                "finish setting up your iCloud service"
-            )
+            reason = reason + ". Please log into https://icloud.com/ to manually finish setting up your iCloud service"
             api_error = ICloudPyServiceNotActivatedException(reason, code)
             LOGGER.error(api_error)
 
@@ -249,17 +239,19 @@ class ICloudPyService:
         try:
             with open(self.session_path, encoding="utf-8") as session_f:
                 self.session_data = json.load(session_f)
-        except:  # pylint: disable=bare-except
+        except:  # noqa: E722
             LOGGER.info("Session file does not exist")
         if self.session_data.get("client_id"):
             self.client_id = self.session_data.get("client_id")
+            self.params["clientId"] = self.client_id
         else:
             self.session_data.update({"client_id": self.client_id})
+            self.params["clientId"] = self.client_id
 
         self.session = ICloudPySession(self)
         self.session.verify = verify
         self.session.headers.update(
-            {"Origin": self.home_endpoint, "Referer": f"{self.home_endpoint}/"}
+            {"Origin": self.home_endpoint, "Referer": f"{self.home_endpoint}/"},
         )
 
         cookiejar_path = self.cookiejar_path
@@ -268,7 +260,7 @@ class ICloudPyService:
             try:
                 self.session.cookies.load(ignore_discard=True, ignore_expires=True)
                 LOGGER.debug("Read cookies from %s", cookiejar_path)
-            except:  # pylint: disable=bare-except
+            except:  # noqa: E722
                 # Most likely a pickled cookiejar from earlier versions.
                 # The cookiejar will get replaced with a valid one after
                 # successful authentication.
@@ -277,7 +269,6 @@ class ICloudPyService:
         self.authenticate()
 
         self._drive = None
-        self._files = None
         self._photos = None
 
     def authenticate(self, force_refresh=False, service=None):
@@ -297,12 +288,11 @@ class ICloudPyService:
 
         if not login_successful and service is not None:
             app = self.data["apps"][service]
-            if (
-                "canLaunchWithOneFactor" in app
-                and app["canLaunchWithOneFactor"] is True
-            ):
+            if "canLaunchWithOneFactor" in app and app["canLaunchWithOneFactor"] is True:
                 LOGGER.debug(
-                    "Authenticating as %s for %s", self.user["accountName"], service
+                    "Authenticating as %s for %s",
+                    self.user["accountName"],
+                    service,
                 )
 
                 try:
@@ -317,13 +307,6 @@ class ICloudPyService:
         if not login_successful:
             LOGGER.debug("Authenticating as %s", self.user["accountName"])
 
-            data = dict(self.user)
-
-            data["rememberMe"] = True
-            data["trustTokens"] = []
-            if self.session_data.get("trust_token"):
-                data["trustTokens"] = [self.session_data.get("trust_token")]
-
             headers = self._get_auth_headers()
 
             if self.session_data.get("scnt"):
@@ -332,9 +315,88 @@ class ICloudPyService:
             if self.session_data.get("session_id"):
                 headers["X-Apple-ID-Session-Id"] = self.session_data.get("session_id")
 
+            class SrpPassword:
+                def __init__(self, password: str):
+                    self.password = password
+
+                def set_encrypt_info(
+                    self,
+                    salt: bytes,
+                    iterations: int,
+                    key_length: int,
+                ):
+                    self.salt = salt
+                    self.iterations = iterations
+                    self.key_length = key_length
+
+                def encode(self):
+                    password_hash = hashlib.sha256(
+                        self.password.encode("utf-8"),
+                    ).digest()
+                    return hashlib.pbkdf2_hmac(
+                        "sha256",
+                        password_hash,
+                        salt,
+                        iterations,
+                        key_length,
+                    )
+
+            srp_password = SrpPassword(self.user["password"])
+            srp.rfc5054_enable()
+            srp.no_username_in_x()
+            usr = srp.User(
+                self.user["accountName"],
+                srp_password,
+                hash_alg=srp.SHA256,
+                ng_type=srp.NG_2048,
+            )
+
+            uname, a_bytes = usr.start_authentication()
+
+            data = {
+                "a": base64.b64encode(a_bytes).decode(),
+                "accountName": uname,
+                "protocols": ["s2k", "s2k_fo"],
+            }
+
+            try:
+                response = self.session.post(
+                    f"{self.auth_endpoint}/signin/init",
+                    data=json.dumps(data),
+                    headers=headers,
+                )
+                response.raise_for_status()
+            except ICloudPyAPIResponseException as error:
+                msg = "Failed to initiate srp authentication."
+                raise ICloudPyFailedLoginException(msg, error) from error
+
+            body = response.json()
+
+            salt = base64.b64decode(body["salt"])
+            b = base64.b64decode(body["b"])
+            c = body["c"]
+            iterations = body["iteration"]
+            key_length = 32
+            srp_password.set_encrypt_info(salt, iterations, key_length)
+
+            m1 = usr.process_challenge(salt, b)
+            m2 = usr.H_AMK
+
+            data = {
+                "accountName": uname,
+                "c": c,
+                "m1": base64.b64encode(m1).decode(),
+                "m2": base64.b64encode(m2).decode(),
+                "rememberMe": True,
+                "trustTokens": [],
+            }
+
+            if self.session_data.get("trust_token"):
+                data["trustTokens"] = [self.session_data.get("trust_token")]
+
             try:
                 self.session.post(
-                    f"{self.auth_endpoint}/signin",
+                    f"{self.auth_endpoint}/signin/complete",
                     params={"isRememberMeEnabled": "true"},
                     data=json.dumps(data),
                     headers=headers,
@@ -360,7 +422,8 @@ class ICloudPyService:
 
         try:
             req = self.session.post(
-                f"{self.setup_endpoint}/accountLogin", data=json.dumps(data)
+                f"{self.setup_endpoint}/accountLogin",
+                data=json.dumps(data),
             )
             self.data = req.json()
         except ICloudPyAPIResponseException as error:
@@ -377,7 +440,8 @@ class ICloudPyService:
 
         try:
             self.session.post(
-                f"{self.setup_endpoint}/accountLogin", data=json.dumps(data)
+                f"{self.setup_endpoint}/accountLogin",
+                data=json.dumps(data),
             )
 
             self.data = self._validate_token()
@@ -398,7 +462,7 @@ class ICloudPyService:
 
     def _get_auth_headers(self, overrides=None):
         headers = {
-            "Accept": "*/*",
+            "Accept": "application/json, text/javascript",
             "Content-Type": "application/json",
             "X-Apple-OAuth-Client-Id": "d39ba9916b7251055b22c7f910e2ea796ee65e98b2ddecea8f5dde8d9d1a815d",
             "X-Apple-OAuth-Client-Type": "firstPartyAuth",
@@ -426,8 +490,7 @@ class ICloudPyService:
         """Get path for session data file."""
         return path.join(
             self._cookie_directory,
-            "".join([c for c in self.user.get("accountName") if match(r"\w", c)])
-            + ".session",
+            "".join([c for c in self.user.get("accountName") if match(r"\w", c)]) + ".session",
         )
 
     @property
@@ -453,7 +516,8 @@ class ICloudPyService:
     def trusted_devices(self):
         """Returns devices trusted for two-step authentication."""
         request = self.session.get(
-            f"{self.setup_endpoint}/listDevices", params=self.params
+            f"{self.setup_endpoint}/listDevices",
+            params=self.params,
         )
         return request.json().get("devices")
 
@@ -543,7 +607,8 @@ class ICloudPyService:
         """Get webservice URL, raise an exception if not exists."""
         if self._webservices.get(ws_key) is None:
             raise ICloudPyServiceNotActivatedException(
-                "Webservice not available", ws_key
+                "Webservice not available",
+                ws_key,
             )
         return self._webservices[ws_key]["url"]
 
@@ -552,7 +617,10 @@ class ICloudPyService:
         """Returns all devices."""
         service_root = self._get_webservice_url("findme")
         return FindMyiPhoneServiceManager(
-            service_root, self.session, self.params, self.with_family
+            service_root,
+            self.session,
+            self.params,
+            self.with_family,
         )
 
     @property
@@ -566,14 +634,6 @@ class ICloudPyService:
         service_root = self._get_webservice_url("account")
         return AccountService(service_root, self.session, self.params)
 
-    @property
-    def files(self):
-        """Gets the 'File' service."""
-        if not self._files:
-            service_root = self._get_webservice_url("ubiquity")
-            self._files = UbiquityService(service_root, self.session, self.params)
-        return self._files
-
     @property
     def photos(self):
         """Gets the 'Photo' service."""
@@ -616,10 +676,7 @@ class ICloudPyService:
         return f"iCloud API: {self.user.get('accountName')}"
 
     def __str__(self):
-        as_unicode = self.__unicode__()
-        if PY2:
-            return as_unicode.encode("utf-8", "ignore")
-        return as_unicode
+        return self.__unicode__()
 
     def __repr__(self):
         return f"<{str(self)}>"
