@@ -4,8 +4,6 @@
 class ICloudPyException(Exception):
     """Generic iCloud exception."""
 
-    pass
-
 
 # API
 class ICloudPyAPIResponseException(ICloudPyException):
@@ -16,7 +14,7 @@ class ICloudPyAPIResponseException(ICloudPyException):
         self.code = code
         message = reason or ""
         if code:
-            message += " (%s)" % code
+            message += f" ({code})"
         if retry:
             message += ". Retrying ..."
 
@@ -26,32 +24,24 @@ class ICloudPyAPIResponseException(ICloudPyException):
 class ICloudPyServiceNotActivatedException(ICloudPyAPIResponseException):
     """iCloud service not activated exception."""
 
-    pass
-
 
 # Login
 class ICloudPyFailedLoginException(ICloudPyException):
     """iCloud failed login exception."""
 
-    pass
-
 
 class ICloudPy2SARequiredException(ICloudPyException):
     """iCloud 2SA required exception."""
 
     def __init__(self, apple_id):
-        message = "Two-step authentication required for account: %s" % apple_id
+        message = f"Two-step authentication required for account:{apple_id}"
         super().__init__(message)
 
 
 class ICloudPyNoStoredPasswordAvailableException(ICloudPyException):
     """iCloud no stored password exception."""
 
-    pass
-
 
 # Webservice specific
 class ICloudPyNoDevicesException(ICloudPyException):
     """iCloud no device exception."""
-
-    pass
