@@ -1,8 +1,6 @@
 """Account service."""
 from collections import OrderedDict
 
-from six import PY2
-
 from icloudpy.utils import underscore_to_camelcase
 
 
@@ -53,7 +51,7 @@ class AccountService:
                         self.session,
                         self.params,
                         self._acc_family_member_photo_url,
-                    )
+                    ),
                 )
 
         return self._family
@@ -74,10 +72,7 @@ class AccountService:
         return f"{{devices: {len(self.devices)}, family: {len(self.family)}, storage: {storage_available} bytes free}}"
 
     def __str__(self):
-        as_unicode = self.__unicode__()
-        if PY2:
-            return as_unicode.encode("utf-8", "ignore")
-        return as_unicode
+        return self.__unicode__()
 
     def __repr__(self):
         return f"<{type(self).__name__}: {str(self)}>"
@@ -93,10 +88,7 @@ class AccountDevice(dict):
         return f"{{model: {self.model_display_name}, name: {self.name}}}"
 
     def __str__(self):
-        as_unicode = self.__unicode__()
-        if PY2:
-            return as_unicode.encode("utf-8", "ignore")
-        return as_unicode
+        return self.__unicode__()
 
     def __repr__(self):
         return f"<{type(self).__name__}: {str(self)}>"
@@ -196,7 +188,7 @@ class FamilyMember:
         params_photo = dict(self._params)
         params_photo.update({"memberId": self.dsid})
         return self._session.get(
-            self._acc_family_member_photo_url, params=params_photo, stream=True
+            self._acc_family_member_photo_url, params=params_photo, stream=True,
         )
 
     def __getitem__(self, key):
@@ -210,10 +202,7 @@ class FamilyMember:
         )
 
     def __str__(self):
-        as_unicode = self.__unicode__()
-        if PY2:
-            return as_unicode.encode("utf-8", "ignore")
-        return as_unicode
+        return self.__unicode__()
 
     def __repr__(self):
         return f"<{type(self).__name__}: {str(self)}>"
@@ -249,10 +238,7 @@ class AccountStorageUsageForMedia:
         return f"{{key: {self.key}, usage: {self.usage_in_bytes} bytes}}"
 
     def __str__(self):
-        as_unicode = self.__unicode__()
-        if PY2:
-            return as_unicode.encode("utf-8", "ignore")
-        return as_unicode
+        return self.__unicode__()
 
     def __repr__(self):
         return f"<{type(self).__name__}: {str(self)}>"
@@ -289,7 +275,7 @@ class AccountStorageUsage:
     def available_storage_in_percent(self):
         """Gets the available storage in percent."""
         return round(
-            self.available_storage_in_bytes * 100 / self.total_storage_in_bytes, 2
+            self.available_storage_in_bytes * 100 / self.total_storage_in_bytes, 2,
         )
 
     @property
@@ -326,10 +312,7 @@ class AccountStorageUsage:
         return f"{self.used_storage_in_percent}% used of {self.total_storage_in_bytes} bytes"
 
     def __str__(self):
-        as_unicode = self.__unicode__()
-        if PY2:
-            return as_unicode.encode("utf-8", "ignore")
-        return as_unicode
+        return self.__unicode__()
 
     def __repr__(self):
         return f"<{type(self).__name__}: {str(self)}>"
@@ -340,23 +323,20 @@ class AccountStorage:
 
     def __init__(self, storage_data):
         self.usage = AccountStorageUsage(
-            storage_data.get("storageUsageInfo"), storage_data.get("quotaStatus")
+            storage_data.get("storageUsageInfo"), storage_data.get("quotaStatus"),
         )
         self.usages_by_media = OrderedDict()
 
         for usage_media in storage_data.get("storageUsageByMedia"):
             self.usages_by_media[usage_media["mediaKey"]] = AccountStorageUsageForMedia(
-                usage_media
+                usage_media,
             )
 
     def __unicode__(self):
         return f"{{usage: {self.usage}, usages_by_media: {self.usages_by_media}}}"
 
     def __str__(self):
-        as_unicode = self.__unicode__()
-        if PY2:
-            return as_unicode.encode("utf-8", "ignore")
-        return as_unicode
+        return self.__unicode__()
 
     def __repr__(self):
         return f"<{type(self).__name__}: {str(self)}>"
