@@ -1,4 +1,5 @@
 """Calendar service."""
+
 from calendar import monthrange
 from datetime import datetime
 
@@ -30,9 +31,9 @@ class CalendarService:
         params.update(
             {
                 "lang": "en-us",
-                "usertz": get_localzone().zone,
+                "usertz": str(get_localzone()),
                 "dsid": self.session.service.data["dsInfo"]["dsid"],
-            }
+            },
         )
         url = f"{self._calendar_event_detail_url}/{pguid}/{guid}"
         req = self.session.get(url, params=params)
@@ -46,20 +47,20 @@ class CalendarService:
         have been given, the range becomes this month.
         """
         today = datetime.today()
-        first_day, last_day = monthrange(today.year, today.month)
+        _, last_day = monthrange(today.year, today.month)
         if not from_dt:
-            from_dt = datetime(today.year, today.month, first_day)
+            from_dt = datetime(today.year, today.month, 1)
         if not to_dt:
             to_dt = datetime(today.year, today.month, last_day)
         params = dict(self.params)
         params.update(
             {
                 "lang": "en-us",
-                "usertz": get_localzone().zone,
+                "usertz": str(get_localzone()),
                 "startDate": from_dt.strftime("%Y-%m-%d"),
                 "endDate": to_dt.strftime("%Y-%m-%d"),
                 "dsid": self.session.service.data["dsInfo"]["dsid"],
-            }
+            },
         )
         req = self.session.get(self._calendar_refresh_url, params=params)
         self.response = req.json()
@@ -76,18 +77,18 @@ class CalendarService:
         Retrieves calendars of this month.
         """
         today = datetime.today()
-        first_day, last_day = monthrange(today.year, today.month)
-        from_dt = datetime(today.year, today.month, first_day)
+        _, last_day = monthrange(today.year, today.month)
+        from_dt = datetime(today.year, today.month, 1)
         to_dt = datetime(today.year, today.month, last_day)
         params = dict(self.params)
         params.update(
             {
                 "lang": "en-us",
-                "usertz": get_localzone().zone,
+                "usertz": str(get_localzone()),
                 "startDate": from_dt.strftime("%Y-%m-%d"),
                 "endDate": to_dt.strftime("%Y-%m-%d"),
                 "dsid": self.session.service.data["dsInfo"]["dsid"],
-            }
+            },
         )
         req = self.session.get(self._calendars, params=params)
         self.response = req.json()
