@@ -1,4 +1,5 @@
 """Drive service."""
+
 import io
 import json
 import mimetypes
@@ -8,7 +9,6 @@ from datetime import datetime, timedelta
 from re import search
 
 from requests import Response
-from six import PY2
 
 
 class DriveService:
@@ -40,8 +40,8 @@ class DriveService:
                     {
                         "drivewsid": drivewsid,
                         "partialData": False,
-                    }
-                ]
+                    },
+                ],
             ),
         )
         if not request.ok:
@@ -68,14 +68,19 @@ class DriveService:
             raise KeyError("'data_token' nor 'package_token' found in response.")
 
     def get_app_data(self):
-        """Returns the app library (previously ubiquity)."""
+        """Returns the app library."""
         request = self.session.get(
-            self._service_root + "/retrieveAppLibraries", params=self.params
+            self._service_root + "/retrieveAppLibraries",
+            params=self.params,
         )
         if not request.ok:
             self.session.raise_error(request.status_code, request.reason)
         return request.json()["items"]
 
+    def get_app_node(self, app_id, folder="documents"):
+        """Returns the node of the app."""
+        return DriveNode(self, self.get_node_data("FOLDER::" + app_id + "::" + folder))
+
     def _get_upload_contentws_url(self, file_object, zone="com.apple.CloudDocs"):
         """Get the contentWS endpoint URL to add a new file."""
         content_type = mimetypes.guess_type(file_object.name)[0]
@@ -101,7 +106,7 @@ class DriveService:
                     "type": "FILE",
                     "content_type": content_type,
                     "size": file_size,
-                }
+                },
             ),
         )
         if not request.ok:
@@ -109,7 +114,12 @@ class DriveService:
         return (request.json()[0]["document_id"], request.json()[0]["url"])
 
     def _update_contentws(
-        self, folder_id, sf_info, document_id, file_object, zone="com.apple.CloudDocs"
+        self,
+        folder_id,
+        sf_info,
+        document_id,
+        file_object,
+        zone="com.apple.CloudDocs",
     ):
         data = {
             "data": {
@@ -159,7 +169,11 @@ class DriveService:
         content_response = request.json()["singleFile"]
 
         self._update_contentws(
-            folder_id, content_response, document_id, file_object, zone
+            folder_id,
+            content_response,
+            document_id,
+            file_object,
+            zone,
         )
 
     def create_folders(self, parent, name):
@@ -175,9 +189,9 @@ class DriveService:
                         {
                             "clientId": self.params["clientId"],
                             "name": name,
-                        }
+                        },
                     ],
-                }
+                },
             ),
         )
         return request.json()
@@ -194,9 +208,9 @@ class DriveService:
                             "drivewsid": node_id,
                             "etag": etag,
                             "name": name,
-                        }
+                        },
                     ],
-                }
+                },
             ),
         )
         return request.json()
@@ -213,9 +227,9 @@ class DriveService:
                             "drivewsid": node_id,
                             "etag": etag,
                             "clientId": self.params["clientId"],
-                        }
+                        },
                     ],
-                }
+                },
             ),
         )
         if not request.ok:
@@ -227,7 +241,8 @@ class DriveService:
         """Returns the root node."""
         if not self._root:
             self._root = DriveNode(
-                self, self.get_node_data("FOLDER::com.apple.CloudDocs::root")
+                self,
+                self.get_node_data("FOLDER::com.apple.CloudDocs::root"),
             )
         return self._root
 
@@ -250,7 +265,7 @@ class DriveNode:
     def name(self):
         """Gets the node name."""
         if "extension" in self.data:
-            return f'{self.data["name"]}.{self.data["extension"]}'
+            return f"{self.data['name']}.{self.data['extension']}"
         return self.data["name"]
 
     @property
@@ -265,11 +280,8 @@ class DriveNode:
             if "items" not in self.data:
                 self.data.update(self.connection.get_node_data(self.data["drivewsid"]))
             if "items" not in self.data:
-                raise KeyError(f'No items in folder, status: {self.data["status"]}')
-            self._children = [
-                DriveNode(self.connection, item_data)
-                for item_data in self.data["items"]
-            ]
+                raise KeyError(f"No items in folder, status: {self.data['status']}")
+            self._children = [DriveNode(self.connection, item_data) for item_data in self.data["items"]]
         return self._children
 
     @property
@@ -308,13 +320,18 @@ class DriveNode:
             response.raw = io.BytesIO()
             return response
         return self.connection.get_file(
-            self.data["docwsid"], zone=self.data["zone"], **kwargs
+            self.data["docwsid"],
+            zone=self.data["zone"],
+            **kwargs,
         )
 
     def upload(self, file_object, **kwargs):
         """ "Upload a new file."""
         return self.connection.send_file(
-            self.data["docwsid"], file_object, zone=self.data["zone"], **kwargs
+            self.data["docwsid"],
+            file_object,
+            zone=self.data["zone"],
+            **kwargs,
         )
 
     def dir(self):
@@ -325,18 +342,25 @@ class DriveNode:
 
     def mkdir(self, folder):
         """Create a new directory directory."""
+        # remove cached entries information first so that it will be re-read on next get_children()
+        self._children = None
+        if "items" in self.data:
+            self.data.pop("items")
         return self.connection.create_folders(self.data["drivewsid"], folder)
 
     def rename(self, name):
         """Rename an iCloud Drive item."""
         return self.connection.rename_items(
-            self.data["drivewsid"], self.data["etag"], name
+            self.data["drivewsid"],
+            self.data["etag"],
+            name,
         )
 
     def delete(self):
         """Delete an iCloud Drive item."""
         return self.connection.move_items_to_trash(
-            self.data["drivewsid"], self.data["etag"]
+            self.data["drivewsid"],
+            self.data["etag"],
         )
 
     def get(self, name):
@@ -355,10 +379,7 @@ class DriveNode:
         return f"{{type: {self.type}, name: {self.name}}}"
 
     def __str__(self):
-        as_unicode = self.__unicode__()
-        if PY2:
-            return as_unicode.encode("utf-8", "ignore")
-        return as_unicode
+        return self.__unicode__()
 
     def __repr__(self):
         return f"<{type(self).__name__}: {str(self)}>"
