@@ -1,7 +1,6 @@
 """Find my iPhone service."""
-import json
 
-from six import PY2
+import json
 
 from icloudpy.exceptions import ICloudPyNoDevicesException
 
@@ -43,8 +42,8 @@ class FindMyiPhoneServiceManager:
                         "shouldLocate": True,
                         "selectedDevice": "all",
                         "deviceListVersion": 1,
-                    }
-                }
+                    },
+                },
             ),
         )
         self.response = req.json()
@@ -65,7 +64,7 @@ class FindMyiPhoneServiceManager:
                 self._devices[device_id].update(device_info)
 
         if not self._devices:
-            raise ICloudPyNoDevicesException()
+            raise ICloudPyNoDevicesException
 
     def __getitem__(self, key):
         if isinstance(key, int):
@@ -79,10 +78,7 @@ class FindMyiPhoneServiceManager:
         return str(self._devices)
 
     def __str__(self):
-        as_unicode = self.__unicode__()
-        if PY2:
-            return as_unicode.encode("utf-8", "ignore")
-        return as_unicode
+        return self.__unicode__()
 
     def __repr__(self):
         return str(self)
@@ -142,12 +138,15 @@ class AppleDevice:
                 "device": self.content["id"],
                 "subject": subject,
                 "clientContext": {"fmly": True},
-            }
+            },
         )
         self.session.post(self.sound_url, params=self.params, data=data)
 
     def display_message(
-        self, subject="Find My iPhone Alert", message="This is a note", sounds=False
+        self,
+        subject="Find My iPhone Alert",
+        message="This is a note",
+        sounds=False,
     ):
         """Send a request to the device to play a sound.
 
@@ -160,12 +159,15 @@ class AppleDevice:
                 "sound": sounds,
                 "userText": True,
                 "text": message,
-            }
+            },
         )
         self.session.post(self.message_url, params=self.params, data=data)
 
     def lost_device(
-        self, number, text="This iPhone has been lost. Please call me.", newpasscode=""
+        self,
+        number,
+        text="This iPhone has been lost. Please call me.",
+        newpasscode="",
     ):
         """Send a request to the device to trigger 'lost mode'.
 
@@ -182,7 +184,7 @@ class AppleDevice:
                 "trackingEnabled": True,
                 "device": self.content["id"],
                 "passcode": newpasscode,
-            }
+            },
         )
         self.session.post(self.lost_url, params=self.params, data=data)
 
@@ -203,10 +205,7 @@ class AppleDevice:
         return f"{display_name}: {name}"
 
     def __str__(self):
-        as_unicode = self.__unicode__()
-        if PY2:
-            return as_unicode.encode("utf-8", "ignore")
-        return as_unicode
+        return self.__unicode__()
 
     def __repr__(self):
         return f"<AppleDevice({self})>"
