@@ -1,21 +1,26 @@
 """Photo service."""
+
 import base64
 import json
+import logging
 from datetime import datetime
 
 # fmt: off
 from urllib.parse import urlencode  # pylint: disable=bad-option-value,relative-import
 
 from pytz import UTC
-from six import PY2
-
-from icloudpy.exceptions import ICloudPyServiceNotActivatedException
 
 # fmt: on
+from icloudpy.exceptions import ICloudPyServiceNotActivatedException
+
+LOGGER = logging.getLogger(__name__)
 
 
-class PhotosService:
-    """The 'Photos' iCloud service."""
+class PhotoLibrary:
+    """Represents a library in the user's photos.
+
+    This provides access to all the albums as well as the photos.
+    """
 
     SMART_FOLDERS = {
         "All Photos": {
@@ -33,7 +38,7 @@ class PhotosService:
                     "fieldName": "smartAlbum",
                     "comparator": "EQUALS",
                     "fieldValue": {"type": "STRING", "value": "TIMELAPSE"},
-                }
+                },
             ],
         },
         "Videos": {
@@ -45,7 +50,7 @@ class PhotosService:
                     "fieldName": "smartAlbum",
                     "comparator": "EQUALS",
                     "fieldValue": {"type": "STRING", "value": "VIDEO"},
-                }
+                },
             ],
         },
         "Slo-mo": {
@@ -57,7 +62,7 @@ class PhotosService:
                     "fieldName": "smartAlbum",
                     "comparator": "EQUALS",
                     "fieldValue": {"type": "STRING", "value": "SLOMO"},
-                }
+                },
             ],
         },
         "Bursts": {
@@ -75,7 +80,7 @@ class PhotosService:
                     "fieldName": "smartAlbum",
                     "comparator": "EQUALS",
                     "fieldValue": {"type": "STRING", "value": "FAVORITE"},
-                }
+                },
             ],
         },
         "Panoramas": {
@@ -87,7 +92,7 @@ class PhotosService:
                     "fieldName": "smartAlbum",
                     "comparator": "EQUALS",
                     "fieldValue": {"type": "STRING", "value": "PANORAMA"},
-                }
+                },
             ],
         },
         "Screenshots": {
@@ -99,7 +104,7 @@ class PhotosService:
                     "fieldName": "smartAlbum",
                     "comparator": "EQUALS",
                     "fieldValue": {"type": "STRING", "value": "SCREENSHOT"},
-                }
+                },
             ],
         },
         "Live": {
@@ -111,7 +116,7 @@ class PhotosService:
                     "fieldName": "smartAlbum",
                     "comparator": "EQUALS",
                     "fieldValue": {"type": "STRING", "value": "LIVE"},
-                }
+                },
             ],
         },
         "Recently Deleted": {
@@ -128,99 +133,88 @@ class PhotosService:
         },
     }
 
-    def __init__(self, service_root, session, params):
-        self.session = session
-        self.params = dict(params)
-        self._service_root = service_root
-        self.service_endpoint = (
-            f"{self._service_root}/database/1/com.apple.photos.cloud/production/private"
-        )
+    def __init__(self, service, zone_id):
+        self.service = service
+        self.zone_id = zone_id
 
         self._albums = None
 
-        self.params.update({"remapEnums": True, "getCurrentSyncToken": True})
-
-        url = f"{self.service_endpoint}/records/query?{urlencode(self.params)}"
-        json_data = (
-            '{"query":{"recordType":"CheckIndexingState"},'
-            '"zoneID":{"zoneName":"PrimarySync"}}'
+        url = f"{self.service._service_endpoint}/records/query?{urlencode(self.service.params)}"
+        json_data = json.dumps(
+            {
+                "query": {"recordType": "CheckIndexingState"},
+                "zoneID": self.zone_id,
+            },
         )
-        request = self.session.post(
-            url, data=json_data, headers={"Content-type": "text/plain"}
+
+        request = self.service.session.post(
+            url,
+            data=json_data,
+            headers={"Content-type": "text/plain"},
         )
         response = request.json()
         indexing_state = response["records"][0]["fields"]["state"]["value"]
         if indexing_state != "FINISHED":
             raise ICloudPyServiceNotActivatedException(
-                "iCloud Photo Library not finished indexing. "
-                "Please try again in a few minutes."
+                ("iCloud Photo Library not finished indexing.  Please try " "again in a few minutes"),
+                None,
             )
 
-        # TODO: Does syncToken ever change?  # pylint: disable=fixme
-        # self.params.update({
-        #     'syncToken': response['syncToken'],
-        #     'clientInstanceId': self.params.pop('clientId')
-        # })
-
-        self._photo_assets = {}
-
     @property
     def albums(self):
-        """Returns photo albums."""
         if not self._albums:
-            self._albums = {}
-            for (name, props) in self.SMART_FOLDERS.items():
-                self._albums[name] = PhotoAlbum(self, name, **props)
+            self._albums = {
+                name: PhotoAlbum(self.service, name, zone_id=self.zone_id, **props)
+                for (name, props) in self.SMART_FOLDERS.items()
+            }
 
             for folder in self._fetch_folders():
-
-                # Skipping albums having null name, that can happen sometime
-                if "albumNameEnc" not in folder["fields"]:
-                    continue
-
-                if folder["recordName"] == "----Root-Folder----" or (
-                    folder["fields"].get("isDeleted")
-                    and folder["fields"]["isDeleted"]["value"]
-                ):
+                if folder["recordName"] in (
+                    "----Root-Folder----",
+                    "----Project-Root-Folder----",
+                ) or (folder["fields"].get("isDeleted") and folder["fields"]["isDeleted"]["value"]):
                     continue
 
                 folder_id = folder["recordName"]
-                folder_obj_type = (
-                    f"CPLContainerRelationNotDeletedByAssetDate:{folder_id}"
-                )
+                folder_obj_type = f"CPLContainerRelationNotDeletedByAssetDate:{folder_id}"
                 folder_name = base64.b64decode(
-                    folder["fields"]["albumNameEnc"]["value"]
+                    folder["fields"]["albumNameEnc"]["value"],
                 ).decode("utf-8")
                 query_filter = [
                     {
                         "fieldName": "parentId",
                         "comparator": "EQUALS",
                         "fieldValue": {"type": "STRING", "value": folder_id},
-                    }
+                    },
                 ]
 
                 album = PhotoAlbum(
-                    self,
-                    name=folder_name,
-                    list_type="CPLContainerRelationLiveByAssetDate",
-                    obj_type=folder_obj_type,
-                    direction="ASCENDING",
-                    query_filter=query_filter,
+                    self.service,
+                    folder_name,
+                    "CPLContainerRelationLiveByAssetDate",
+                    folder_obj_type,
+                    "ASCENDING",
+                    query_filter,
                     folder_id=folder_id,
+                    zone_id=self.zone_id,
                 )
                 self._albums[folder_name] = album
 
         return self._albums
 
     def _fetch_folders(self):
-        url = f"{self.service_endpoint}/records/query?{urlencode(self.params)}"
-        json_data = (
-            '{"query":{"recordType":"CPLAlbumByPositionLive"},'
-            '"zoneID":{"zoneName":"PrimarySync"}}'
+        url = f"{self.service._service_endpoint}/records/query?{urlencode(self.service.params)}"
+        json_data = json.dumps(
+            {
+                "query": {"recordType": "CPLAlbumByPositionLive"},
+                "zoneID": self.zone_id,
+            },
         )
 
-        request = self.session.post(
-            url, data=json_data, headers={"Content-type": "text/plain"}
+        request = self.service.session.post(
+            url,
+            data=json_data,
+            headers={"Content-type": "text/plain"},
         )
         response = request.json()
 
@@ -228,10 +222,59 @@ class PhotosService:
 
     @property
     def all(self):
-        """Returns all photos."""
         return self.albums["All Photos"]
 
 
+class PhotosService(PhotoLibrary):
+    """The 'Photos' iCloud service.
+
+    This also acts as a way to access the user's primary library.
+    """
+
+    def __init__(self, service_root, session, params):
+        self.session = session
+        self.params = dict(params)
+        self._service_root = service_root
+        self._service_endpoint = f"{self._service_root}/database/1/com.apple.photos.cloud/production/private"
+
+        self._libraries = None
+
+        self.params.update({"remapEnums": True, "getCurrentSyncToken": True})
+
+        self._photo_assets = {}
+
+        super().__init__(service=self, zone_id={"zoneName": "PrimarySync"})
+
+    @property
+    def libraries(self):
+        if not self._libraries:
+            try:
+                url = f"{self._service_endpoint}/zones/list"
+                request = self.session.post(
+                    url,
+                    data="{}",
+                    headers={"Content-type": "text/plain"},
+                )
+                response = request.json()
+                zones = response["zones"]
+            except Exception as e:
+                LOGGER.error(f"library exception: {str(e)}")
+
+            libraries = {}
+            for zone in zones:
+                if not zone.get("deleted"):
+                    zone_name = zone["zoneID"]["zoneName"]
+                    libraries[zone_name] = PhotoLibrary(self, zone_id=zone["zoneID"])
+                    # obj_type='CPLAssetByAssetDateWithoutHiddenOrDeleted',
+                    # list_type="CPLAssetAndMasterByAssetDateWithoutHiddenOrDeleted",
+                    # direction="ASCENDING", query_filter=None,
+                    # zone_id=zone['zoneID'])
+
+            self._libraries = libraries
+
+        return self._libraries
+
+
 class PhotoAlbum:
     """A photo album."""
 
@@ -245,6 +288,7 @@ class PhotoAlbum:
         query_filter=None,
         page_size=100,
         folder_id=None,
+        zone_id=None,
     ):
         self.name = name
         self.service = service
@@ -255,6 +299,11 @@ class PhotoAlbum:
         self.page_size = page_size
         self.folder_id = folder_id
 
+        if zone_id:
+            self._zone_id = zone_id
+        else:
+            self._zone_id = "PrimarySync"
+
         self._len = None
 
         self._subalbums = {}
@@ -269,7 +318,7 @@ class PhotoAlbum:
 
     def __len__(self):
         if self._len is None:
-            url = f"{self.service.service_endpoint}/internal/records/query/batch?{urlencode(self.service.params)}"
+            url = f"{self.service._service_endpoint}/internal/records/query/batch?{urlencode(self.service.params)}"
             request = self.service.session.post(
                 url,
                 data=json.dumps(
@@ -289,24 +338,22 @@ class PhotoAlbum:
                                     "recordType": "HyperionIndexCountLookup",
                                 },
                                 "zoneWide": True,
-                                "zoneID": {"zoneName": "PrimarySync"},
-                            }
-                        ]
-                    }
+                                "zoneID": {"zoneName": self._zone_id["zoneName"]},
+                            },
+                        ],
+                    },
                 ),
                 headers={"Content-type": "text/plain"},
             )
             response = request.json()
 
-            self._len = response["batch"][0]["records"][0]["fields"]["itemCount"][
-                "value"
-            ]
+            self._len = response["batch"][0]["records"][0]["fields"]["itemCount"]["value"]
 
         return self._len
 
     def _fetch_subalbums(self):
-        url = (f"{self.service.service_endpoint}/records/query?") + urlencode(
-            self.service.params
+        url = (f"{self.service._service_endpoint}/records/query?") + urlencode(
+            self.service.params,
         )
         # pylint: disable=consider-using-f-string
         query = """{{
@@ -324,10 +371,11 @@ class PhotoAlbum:
                     ]
                 }},
                 "zoneID": {{
-                    "zoneName":"PrimarySync"
+                    "zoneName":"{}"
                 }}
             }}""".format(
-            self.folder_id
+            self.folder_id,
+            self._zone_id["zoneName"],
         )
         json_data = query
         request = self.service.session.post(
@@ -344,25 +392,20 @@ class PhotoAlbum:
         """Returns the subalbums"""
         if not self._subalbums and self.folder_id:
             for folder in self._fetch_subalbums():
-                if (
-                    folder["fields"].get("isDeleted")
-                    and folder["fields"]["isDeleted"]["value"]
-                ):
+                if folder["fields"].get("isDeleted") and folder["fields"]["isDeleted"]["value"]:
                     continue
 
                 folder_id = folder["recordName"]
-                folder_obj_type = (
-                    f"CPLContainerRelationNotDeletedByAssetDate:{folder_id}"
-                )
+                folder_obj_type = f"CPLContainerRelationNotDeletedByAssetDate:{folder_id}"
                 folder_name = base64.b64decode(
-                    folder["fields"]["albumNameEnc"]["value"]
+                    folder["fields"]["albumNameEnc"]["value"],
                 ).decode("utf-8")
                 query_filter = [
                     {
                         "fieldName": "parentId",
                         "comparator": "EQUALS",
                         "fieldValue": {"type": "STRING", "value": folder_id},
-                    }
+                    },
                 ]
 
                 album = PhotoAlbum(
@@ -373,6 +416,7 @@ class PhotoAlbum:
                     direction="ASCENDING",
                     query_filter=query_filter,
                     folder_id=folder_id,
+                    zone_id=self._zone_id,
                 )
                 self._subalbums[folder_name] = album
         return self._subalbums
@@ -386,15 +430,18 @@ class PhotoAlbum:
             offset = 0
 
         while True:
-            url = (f"{self.service.service_endpoint}/records/query?") + urlencode(
-                self.service.params
+            url = (f"{self.service._service_endpoint}/records/query?") + urlencode(
+                self.service.params,
             )
             request = self.service.session.post(
                 url,
                 data=json.dumps(
                     self._list_query_gen(
-                        offset, self.list_type, self.direction, self.query_filter
-                    )
+                        offset,
+                        self.list_type,
+                        self.direction,
+                        self.query_filter,
+                    ),
                 ),
                 headers={"Content-type": "text/plain"},
             )
@@ -419,7 +466,9 @@ class PhotoAlbum:
                 for master_record in master_records:
                     record_name = master_record["recordName"]
                     yield PhotoAsset(
-                        self.service, master_record, asset_records[record_name]
+                        self.service,
+                        master_record,
+                        asset_records[record_name],
                     )
             else:
                 break
@@ -524,6 +573,7 @@ class PhotoAlbum:
                 "burstFlagsExt",
                 "burstId",
                 "captionEnc",
+                "extendedDescEnc",
                 "locationEnc",
                 "locationV2Enc",
                 "locationLatitude",
@@ -540,8 +590,11 @@ class PhotoAlbum:
                 "itemId",
                 "position",
                 "isKeyAsset",
+                "importedByBundleIdentifierEnc",
+                "importedByDisplayNameEnc",
+                "importedBy",
             ],
-            "zoneID": {"zoneName": "PrimarySync"},
+            "zoneID": self._zone_id,
         }
 
         if query_filter:
@@ -553,10 +606,7 @@ class PhotoAlbum:
         return self.title
 
     def __str__(self):
-        as_unicode = self.__unicode__()
-        if PY2:
-            return as_unicode.encode("utf-8", "ignore")
-        return as_unicode
+        return self.__unicode__()
 
     def __repr__(self):
         return f"<{type(self).__name__}: '{self}'>"
@@ -573,15 +623,21 @@ class PhotoAsset:
         self._versions = None
 
     PHOTO_VERSION_LOOKUP = {
-        "original": "resOriginal",
+        "full": "resJPEGFull",
+        "large": "resJPEGLarge",
         "medium": "resJPEGMed",
         "thumb": "resJPEGThumb",
+        "sidecar": "resSidecar",
+        "original": "resOriginal",
+        "original_alt": "resOriginalAlt",
     }
 
     VIDEO_VERSION_LOOKUP = {
-        "original": "resOriginal",
+        "full": "resVidFull",
         "medium": "resVidMed",
         "thumb": "resVidSmall",
+        "original": "resOriginal",
+        "original_compl": "resOriginalVidCompl",
     }
 
     @property
@@ -592,9 +648,13 @@ class PhotoAsset:
     @property
     def filename(self):
         """Gets the photo file name."""
-        return base64.b64decode(
-            self._master_record["fields"]["filenameEnc"]["value"]
-        ).decode("utf-8")
+        try:
+            return base64.b64decode(
+                self._master_record["fields"]["filenameEnc"]["value"],
+            ).decode("utf-8")
+        except KeyError:
+            # Some photos/videos (e.g., GoPro videos) may not have a filename
+            return None
 
     @property
     def size(self):
@@ -611,7 +671,8 @@ class PhotoAsset:
         """Gets the photo asset date."""
         try:
             return datetime.fromtimestamp(
-                self._asset_record["fields"]["assetDate"]["value"] / 1000.0, tz=UTC
+                self._asset_record["fields"]["assetDate"]["value"] / 1000.0,
+                tz=UTC,
             )
         except KeyError:
             return datetime.fromtimestamp(0)
@@ -620,7 +681,8 @@ class PhotoAsset:
     def added_date(self):
         """Gets the photo added date."""
         return datetime.fromtimestamp(
-            self._asset_record["fields"]["addedDate"]["value"] / 1000.0, tz=UTC
+            self._asset_record["fields"]["addedDate"]["value"] / 1000.0,
+            tz=UTC,
         )
 
     @property
@@ -682,41 +744,40 @@ class PhotoAsset:
             return None
 
         return self._service.session.get(
-            self.versions[version]["url"], stream=True, **kwargs
+            self.versions[version]["url"],
+            stream=True,
+            **kwargs,
         )
 
     def delete(self):
         """Deletes the photo."""
-        json_data = (
-            '{"query":{"recordType":"CheckIndexingState"},'
-            '"zoneID":{"zoneName":"PrimarySync"}}'
-        )
-        # pylint: disable=consider-using-f-string
-        json_data = (
-            '{"operations":[{'
-            '"operationType":"update",'
-            '"record":{'
-            '"recordName":"%s",'
-            '"recordType":"%s",'
-            '"recordChangeTag":"%s",'
-            '"fields":{"isDeleted":{"value":1}'
-            "}}}],"
-            '"zoneID":{'
-            '"zoneName":"PrimarySync"'
-            '},"atomic":true}'
-            % (
-                self._asset_record["recordName"],
-                self._asset_record["recordType"],
-                self._master_record["recordChangeTag"],
-            )
+        json_data = json.dumps(
+            {
+                "atomic": True,
+                "desiredKeys": ["isDeleted"],
+                "operations": [
+                    {
+                        "operationType": "update",
+                        "record": {
+                            "fields": {"isDeleted": {"value": 1}},
+                            "recordChangeTag": self._asset_record["recordChangeTag"],
+                            "recordName": self._asset_record["recordName"],
+                            "recordType": self._asset_record["recordType"],
+                        },
+                    },
+                ],
+                "zoneID": self._service.zone_id,
+            },
         )
 
-        endpoint = self._service.service_endpoint
+        endpoint = self._service._service_endpoint
         params = urlencode(self._service.params)
         url = f"{endpoint}/records/modify?{params}"
 
         return self._service.session.post(
-            url, data=json_data, headers={"Content-type": "text/plain"}
+            url,
+            data=json_data,
+            headers={"Content-type": "text/plain"},
         )
 
     def __repr__(self):
